==> nmsg-0.3.0-pre1.tar.gz: nmsg-0.3.0-pre1/nmsg/isc/nmsgpb_isc_email.c <==
/* nmsgpb_isc_email.c - email protobuf nmsg module */

/*
 * Copyright (c) 2008, 2009 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* Import. */

#include <nmsg.h>

#include "nmsgpb_isc_email.h"
#include "email.pb-c.c"

/* Data. */

struct nmsg_pbmod_field email_fields[] = {
	{ .type = nmsg_pbmod_ft_enum,		.name = "type"		},
	{ .type = nmsg_pbmod_ft_mlstring,	.name = "headers"	},
	{ .type = nmsg_pbmod_ft_ip,		.name = "srcip"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "srchost"	},
	{ .type = nmsg_pbmod_ft_string,		.name = "helo"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "from"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "rcpt"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "bodyurl"	},
	NMSG_PBMOD_FIELD_END
};

/* Export. */

struct nmsg_pbmod nmsg_pbmod_ctx = {
	.pbmver		= NMSG_PBMOD_VERSION,
	.pbdescr	= &nmsg__isc__email__descriptor,
	.pbfields	= nmsg__isc__email__field_descriptors,
	.fields		= email_fields,
	.vendor		= NMSG_VENDOR_ISC,
	.msgtype	= { MSGTYPE_EMAIL_ID, MSGTYPE_EMAIL_NAME }
};

==> nmsg-0.3.3.tar.gz: nmsg-0.3.3/nmsg/isc/nmsgpb_isc_email.c <==
/* nmsgpb_isc_email.c - email protobuf nmsg module */

/*
 * Copyright (c) 2008, 2009 by Internet Systems Consortium, Inc. ("ISC")
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/* Import. */

#include <nmsg.h>

#include "nmsgpb_isc_email.h"
#include "email.pb-c.c"

/* Data. */

struct nmsg_pbmod_field email_fields[] = {
	{ .type = nmsg_pbmod_ft_enum,		.name = "type"		},
	{ .type = nmsg_pbmod_ft_mlstring,	.name = "headers"	},
	{ .type = nmsg_pbmod_ft_ip,		.name = "srcip"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "srchost"	},
	{ .type = nmsg_pbmod_ft_string,		.name = "helo"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "from"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "rcpt"		},
	{ .type = nmsg_pbmod_ft_string,		.name = "bodyurl"	},
	NMSG_PBMOD_FIELD_END
};

/* Export. */

struct nmsg_pbmod nmsg_pbmod_ctx = {
	.pbmver		= NMSG_PBMOD_VERSION,
	.vendor		= NMSG_VENDOR_ISC,
	.msgtype	= { MSGTYPE_EMAIL_ID, MSGTYPE_EMAIL_NAME },

	.pbdescr	= &nmsg__isc__email__descriptor,
	.pbfields	= nmsg__isc__email__field_descriptors,
	.fields		= email_fields
};
